@@ -1,8 +1,10 @@
 from pysite.exceptions.conf import *
 import imp
+from os.path import abspath,dirname,join
 
 class PySiteConfiguration(object):
-	def __init__(self,sitename=None,sitetitle=None,logfile=None):
+	def __init__(self,basedir,sitename=None,sitetitle=None,logfile=None):
+		self.basedir = basedir
 		if sitename:
 			self.sitename = sitename
 			
@@ -17,13 +19,13 @@ class PySiteConfiguration(object):
 		if logfile:
 			self.logfile = logfile
 		elif not getattr(self,'logfile',None):
-			self.logfile = '%s.log' % self.sitename
+			self.logfile = join(self.basedir,'%s.log' % self.sitename)
 
 global_conf = None
 
-def getConfiguration(conffile=None):
+def getConfiguration(basedir=None):
 	global global_conf
 	if not global_conf:
-		confmod = imp.load_source('conf',conffile)
-		global_conf = confmod.siteconf()
+		confmod = imp.load_source('conf',join(basedir,'conf.py'))
+		global_conf = confmod.siteconf(basedir)
 	return global_conf
\ No newline at end of file
