@@ -9,6 +9,7 @@ from pysite.tools.httptools import HTTPRequestData
 from pysite.localization import localization
 from pysite.conf import getConfiguration
 from pysite.compat import PORTABLE_STRING, PORTABLE_BYTES
+import types
 import pysite.wsgi.httpheader
 
 if sys.version_info[0]==2:
@@ -67,6 +68,9 @@ ext_map_content_type = {
 	'jpg': {
 		'Content-Type': 'image/jpeg'
 	},
+	'bmp': {
+		'Content-Type': 'image/bmp'
+	},
 	'ico': {
 		'Content-Type': 'image/x-icon'
 	},
@@ -222,7 +226,30 @@ class PySiteApplication(object):
 			environ['lang'] = lang
 			init = getattr(subhandler,'init',None)
 			if init:
-				init(template_info,response_headers,environ,translate,req_data)
+				try:
+					res = init(template_info,response_headers,environ,translate,req_data)
+					if type(res)==types.GeneratorType:
+						first_iter = True
+						template_off = False
+						for data in res:
+							if first_iter:
+								template_off = template_info.get("template_off",False)
+								if template_off:
+									start_response(status, response_headers)
+								first_iter = False
+							if template_off:
+								yield data
+						if template_off:
+							raise StopIteration
+					elif type(res)==str:
+						template_off = template_info.get("template_off",False)
+						if template_off:
+							start_response(status, response_headers)
+							yield res
+							raise StopIteration
+				except Exception as e:
+					logger.warning(get_traceback())
+					raise e
 			
 			subhandler_redirect = getattr(subhandler,'redirect',None)
 			if subhandler_redirect:
